| Title: | First Steps Around 'narrow' |
|---|---|
| Description: | Leaning on the 'narrow' package for C-level access to 'Arrow' without requiring the full weight of that package. |
| Authors: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-05-18 15:26:02 UTC |
| Source: | https://github.com/eddelbuettel/rcppnarrow |
Leaning on the 'narrow' package for C-level access to 'Arrow' without requiring the full weight of that package.
Index of help topics:
describeArrowArray Describe An Arrow Array describeArrowSchema Describe An Arrow Schema extract_null_count Count Null Elements in Arrow Object narrow_array_info Call array info print_uint64 Print uint64_t vector RcppNarrow-package First Steps Around 'narrow'
Dirk Eddelbuettel <[email protected]>
Dirk Eddelbuettel
Describe An Arrow Array
describeArrowArray(ptr)describeArrowArray(ptr)
ptr |
An external pointer object for an |
None. The function is invoked for the side effect of displaingy some array info.
Describe An Arrow Schema
describeArrowSchema(ptr)describeArrowSchema(ptr)
ptr |
An external pointer object for an |
None. The function is invoked for the side effect of displaying the schema info.
Count Null Elements in Arrow Object
extract_null_count(array_data_xptr)extract_null_count(array_data_xptr)
array_data_xptr |
An external pointer to an Arrow object |
The number of null elements
if (requireNamespace("narrow", quietly=TRUE)) { extract_null_count(narrow::as_narrow_array(c(NA, NA, 1:5))$array_data) }if (requireNamespace("narrow", quietly=TRUE)) { extract_null_count(narrow::as_narrow_array(c(NA, NA, 1:5))$array_data) }
Call array info
narrow_array_info(adptr)narrow_array_info(adptr)
adptr |
An external pointer to array data object |
A list with array info
if (requireNamespace("narrow", quietly=TRUE)) { x <- narrow::as_narrow_array(c(NA, 2, NA, 4:7)) narrow_array_info(x$array_data) }if (requireNamespace("narrow", quietly=TRUE)) { x <- narrow::as_narrow_array(c(NA, 2, NA, 4:7)) narrow_array_info(x$array_data) }
Print uint64_t vector
print_uint64(ptr)print_uint64(ptr)
ptr |
An external pointer object for an |
None. The function is invoked for the side effect of display schema info.